@@ -5,13 +5,11 @@ Entrypoint for the brewblox-dev tool
 import click
 from dotenv import find_dotenv, load_dotenv
 
-from brewblox_dev import docker, localbuild, repository
+from brewblox_dev import repository
 
 cli = click.CommandCollection(
     sources=[
-        localbuild.cli,
         repository.cli,
-        docker.cli,
     ])
 
 
